Learn R Programming

tmle.npvi (version 0.9.3)

as.character.NPVI: Returns a Description

Description

Returns a short string describing the NPVI object.

Usage

## S3 method for class 'NPVI':
as.character(x, ...)

Arguments

x
An object of class TMLE.NPVI.
...
Not used.

Value

  • A character string summarizing the content of the object. The summary contains:
    • The sample size of the data set involved in the TMLE procedure.
  • The value of the TMLE and its estimated standard error.
  • A reminder of the tuning of the stopping criteria, and a report on the convergence of the TMLE procedure (see tmle.npvi).
  • A confidence interval with default level of 95% (the level can be changed by using setConfLevel).
  • The $p$-value of the two-sided test of ``$\Psi(P_0)=0$''.
  • The $p$-value of the two-sided test of ``$\Psi(P_0)=\Phi(P_0)$'', with the estimated value of $\Phi(P_0)$.

See Also

tmle.npvi

Examples

Run this code
FALSE

Run the code above in your browser using DataLab