Learn R Programming

tmle.npvi (version 0.9.3)

getObs.NPVI: Retrieves the Observations

Description

Retrieves the matrix of observations involved in the TMLE procedure.

Usage

## S3 method for class 'NPVI':
getObs(this, tabulate, ...)

Arguments

this
An object of class TMLE.NPVI.
tabulate
A logical, to specify whether it is the original data set that is retrieved (if FALSE) or a tabulated version of it (otherwise), for internal use only. If tabulate is missing then the value attached to the in
...
Not used.

Value

  • Either the original data set involved in the TMLE procedure or a tabulated version of it.

See Also

tmle.npvi

Examples

Run this code
FALSE

Run the code above in your browser using DataLab