Learn R Programming

tmle.npvi (version 0.9.3)

tcga2012brca: Sample breast cancer data from TCGA

Description

Expression, DNA copy number, and DNA methylation data of 125 genes of chromosome 21 for 463 breast cancer samples from TCGA.

Usage

tcga2012brca

Arguments

Details

These data were obtained using the scripts located in testScripts/tcga2012brca. See the tmle-npvi.pdf vignette for more details on the preparation of the data set.

Gene names and genomic coordinates are stored in the names of the list.

References

Chambaz, A., Neuvial, P., & van der Laan, M. J. (2012). Estimation of a non-parametric variable importance measure of a continuous exposure. Electronic journal of statistics, 6, 1059--1099.

Cancer Genome Atlas Network. (2012). Comprehensive molecular portraits of human breast tumours. Nature, 490(7418), 61-70.

Examples

Run this code
data(tcga2012brca)
  nms <- names(tcga2012brca)
  ii <- grep("TP53", nms)
  obs <- tcga2012brca[[ii]]
  pairs(obs, main=nms[ii])

  thr <- 0.02
  whichSmall <- which(abs(obs[, "X"]) <= thr)
  obs[whichSmall, "X"] <- 0

  ## the code below takes ~20s to run
  res <- tmle.npvi(obs)

Run the code above in your browser using DataLab