getPsiSd.NPVI: Returns Current Estimated Standard Deviation of the Estimator
Description
Returns the current value of the estimated standard deviation of the current estimator.
Usage
## S3 method for class 'NPVI':
getPsiSd(this, ...)
Arguments
this
An object of class TMLE.NPVI.
...
Not used.
Value
Retrieves the estimated standard deviation of the current estimator $\Psi(P_n^k)$ of the
parameter of interest. Its computation involves simulation of a large number of
iid copies of $(X,W)$ under $P_n^k$.